@@ -302,24 +302,29 @@ struct UIArrayHolder
 
 namespace Items {
 
-void fill (Gtk::MenuShell& menu_shell,
-           const Items::Array<Items::Info>& info,
-           Glib::RefPtr<Gtk::AccelGroup>& accel_group,
-           bool uline_accels,
-           int pos)
+Array<Info> fill (Gtk::MenuShell                      &menu_shell,
+		  const Array<Info>                   &info,
+		  const Glib::RefPtr<Gtk::AccelGroup> &accel_group,
+		  bool                                 uline_accels,
+		  int                                  pos)
 {
-  menu_shell.set_data ("gnomemm-uihold", new UIArrayHolder (info), UIArrayHolder::destroy);
-  gnome_app_fill_menu (menu_shell.gobj (), info.gobj (),
-		       accel_group->gobj (), (gboolean)uline_accels,
-		       pos);
+  menu_shell.set_data("gnomemm-uihold", new UIArrayHolder(info), UIArrayHolder::destroy);
+  gnome_app_fill_menu(menu_shell.gobj(), info.gobj(),
+		      accel_group ? accel_group->gobj() : 0,
+		      (gboolean)uline_accels, pos);
+
+  return info;
 }
 
-void fill (Gtk::Toolbar& toolbar,
-           const Items::Array<Items::Info>& info,
-           Glib::RefPtr<Gtk::AccelGroup>& accel_group)
+Array<Info> fill (Gtk::Toolbar                        &toolbar,
+		  const Array<Info>                   &info,
+		  const Glib::RefPtr<Gtk::AccelGroup> &accel_group)
 {
-  toolbar.set_data("gnomemm-uihold", new UIArrayHolder(info),UIArrayHolder::destroy);
-  gnome_app_fill_toolbar(toolbar.gobj(), info.gobj(), accel_group->gobj());
+  toolbar.set_data("gnomemm-uihold", new UIArrayHolder(info), UIArrayHolder::destroy);
+  gnome_app_fill_toolbar(toolbar.gobj(), info.gobj(),
+			 accel_group ? accel_group->gobj() : 0);
+
+  return info;
 }
 
 
